@@ -29,6 +29,7 @@ class ApiGatewayRestApi(Resource):
         "Mode": GeneratedProperty(),
         "ApiKeySourceType": GeneratedProperty(),
         "Tags": GeneratedProperty(),
+        "Policy": GeneratedProperty(),
     }
 
     Body: Optional[Dict[str, Any]]
@@ -44,6 +45,7 @@ class ApiGatewayRestApi(Resource):
     Mode: Optional[PassThrough]
     ApiKeySourceType: Optional[PassThrough]
     Tags: Optional[PassThrough]
+    Policy: Optional[PassThrough]
 
     runtime_attrs = {"rest_api_id": lambda self: ref(self.logical_id)}
 
@@ -230,6 +232,25 @@ class ApiGatewayDomainName(Resource):
     OwnershipVerificationCertificateArn: Optional[PassThrough]
 
 
+class ApiGatewayDomainNameV2(Resource):
+    resource_type = "AWS::ApiGateway::DomainNameV2"
+    property_types = {
+        "DomainName": GeneratedProperty(),
+        "EndpointConfiguration": GeneratedProperty(),
+        "SecurityPolicy": GeneratedProperty(),
+        "CertificateArn": GeneratedProperty(),
+        "Tags": GeneratedProperty(),
+        "Policy": GeneratedProperty(),
+    }
+
+    DomainName: PassThrough
+    EndpointConfiguration: Optional[PassThrough]
+    SecurityPolicy: Optional[PassThrough]
+    CertificateArn: Optional[PassThrough]
+    Tags: Optional[PassThrough]
+    Policy: Optional[PassThrough]
+
+
 class ApiGatewayBasePathMapping(Resource):
     resource_type = "AWS::ApiGateway::BasePathMapping"
     property_types = {
@@ -240,6 +261,16 @@ class ApiGatewayBasePathMapping(Resource):
     }
 
 
+class ApiGatewayBasePathMappingV2(Resource):
+    resource_type = "AWS::ApiGateway::BasePathMappingV2"
+    property_types = {
+        "BasePath": GeneratedProperty(),
+        "DomainNameArn": GeneratedProperty(),
+        "RestApiId": GeneratedProperty(),
+        "Stage": GeneratedProperty(),
+    }
+
+
 class ApiGatewayUsagePlan(Resource):
     resource_type = "AWS::ApiGateway::UsagePlan"
     property_types = {
@@ -278,6 +309,16 @@ class ApiGatewayApiKey(Resource):
     runtime_attrs = {"api_key_id": lambda self: ref(self.logical_id)}
 
 
+class ApiGatewayDomainNameAccessAssociation(Resource):
+    resource_type = "AWS::ApiGateway::DomainNameAccessAssociation"
+    property_types = {
+        "AccessAssociationSource": GeneratedProperty(),
+        "AccessAssociationSourceType": GeneratedProperty(),
+        "DomainNameArn": GeneratedProperty(),
+        "Tags": GeneratedProperty(),
+    }
+
+
 class ApiGatewayAuthorizer:
     _VALID_FUNCTION_PAYLOAD_TYPES = [None, "TOKEN", "REQUEST"]
 
