@@ -18,7 +18,7 @@ class RegionConfiguration:
         :return: True, if API Gateway does not support Edge configuration
         """
         partition = ArnGenerator.get_partition_name()
-        if partition.startswith("aws-iso") or partition in ["aws-us-gov", "aws-cn"]:
+        if partition.startswith("aws-iso") or partition in ["aws-us-gov", "aws-cn", "aws-eusc"]:
             return False
         return True
 
